

<p align="center"><img width="150" alt="portfolio_view" src="https://raw.githubusercontent.com/ismet55555/exam-terminal/master/misc/logo.png"></p>

<h1 align="center">exam-terminal</h1>

<!-- Licence Shield from https://shields.io/-->
<p align="center">

<img alt="portfolio_view" src="https://img.shields.io/github/pipenv/locked/dependency-version/ismet55555/exam-terminal/exam-terminal">

<img alt="portfolio_view" src="https://img.shields.io/pypi/pyversions/exam-terminal">

<img alt="portfolio_view" src="https://img.shields.io/pypi/format/exam-terminal">

<img alt="portfolio_view" src="https://img.shields.io/pypi/status/exam-terminal">

<img alt="portfolio_view" src="https://img.shields.io/github/license/ismet55555/exam-terminal">

<img alt="portfolio_view" src="https://img.shields.io/travis/com/ismet55555/exam-terminal/master">
</p>








The exam-terminal is a terminal-based examination tool, which you can potentially do any of the following:

- Construct and take practice exams
- Give quick quizzes

Some mentionable features:

- Exam statistics
- Evaluation PDF

## Installation

- `pip install exam-terminal`

## Quick Start
- `exam-terminal --help`
- `exam-terminal --sample`

## Development Notes

- Clone this repo
- Go into cloned repo directory directory
- `pipenv install --three --dev -e .`
- `pipenv shell`
